@@ -89,7 +89,7 @@ def loglike(pulsar,efac=1.0,equad=None,jitter=None,Ared=None,gammared=None,margi
         # Lentati formulation for correlated noise
         invphi = N.diag(1/phi)
         Ninv = N.diag(1/Cdiag)
-        NinvF = dot(Ninv,F)
+        NinvF = dot(Ninv,F)          # could be accelerated
         X = invphi + dot(F.T,NinvF)  # invphi + FTNinvF
 
         Cinv = Ninv - dot(NinvF,N.linalg.inv(X),NinvF.T)
